@@ -7,7 +7,7 @@ License: BSD, see LICENSE for details.
 For further information visit http://code.indifex.com/django-addons
 """
 
-import sys
+import sys, traceback
 from django.conf import settings
 
 def autodiscover_handlers():
@@ -20,6 +20,7 @@ def autodiscover_handlers():
             __import__(fullname)
         except ImportError, err:
             if str(err) != "No module named handlers":
+                traceback.print_exc()
                 raise err
 
         if fullname in sys.modules:
